summaryrefslogtreecommitdiff
path: root/ipu3.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'ipu3.cpp')
-rw-r--r--ipu3.cpp25
1 files changed, 15 insertions, 10 deletions
diff --git a/ipu3.cpp b/ipu3.cpp
index 4fce647..b8015af 100644
--- a/ipu3.cpp
+++ b/ipu3.cpp
@@ -88,15 +88,17 @@ int IPAIPU3::init(const IPASettings &settings)
int ret;
/*
* Temporary mapping of the sensor name to the AIQB data file.
*
* \todo: This mapping table should be handled more generically
* or through the configuration interfaces perhaps.
*/
std::map<std::string, std::string> aiqb_paths = {
- { "ov13858", "/usr/share/libcamera/ipa/ipu3/00ov13858.aiqb" },
- { "ov5670", "/usr/share/libcamera/ipa/ipu3/01ov5670.aiqb" },
- { "imx258", "/etc/camera/ipu3/00imx258.aiqb" },
+ { "ov13858", "00ov13858.aiqb" },
+ { "ov5670", "01ov5670.aiqb" },
+ { "imx258", "00imx258.aiqb" },
};
LOG(IPAIPU3, Info) << "Initialising IPA IPU3 for "
@@ -108,8 +110,11 @@ int IPAIPU3::init(const IPASettings &settings)
return -EINVAL;
}
- LOG(IPAIPU3, Info) << "Using tuning file: " << it->second;
- ret = aiqb_.load(it->second.c_str());
+ std::string tuningPath = "/etc/camera/ipu3/";
+ std::string tuningFile = tuningPath + it->second;
+
+ LOG(IPAIPU3, Info) << "Using tuning file: " << tuningFile;
+ ret = aiqb_.load(tuningFile.c_str());
if (ret) {
LOG(IPAIPU3, Error) << "Failed to load AIQB";
return -ENODATA;
@@ -88,15 +88,17 @@ int IPAIPU3::init(const IPASettings &settings)
int ret;
/*
- * Temporary mapping of the sensor name to the AIQB data file.
- *
- * \todo: This mapping table should be handled more generically
- * or through the configuration interfaces perhaps.
- */
+ * Temporary mapping of the sensor name to the AIQB data file.
+ *
+ * The tuningPath used here is specific to ChromeOS.
+ *
+ * \todo This mapping table should be handled more generically
+ * or through the configuration interfaces.
+ */
std::map<std::string, std::string> aiqb_paths = {